# dep-check

[![image](https://img.shields.io/pypi/v/dep-check.svg)](https://pypi.python.org/pypi/dep-check)

## Version: Pre-alpha

Python Dependency Check Tool

* Free software: MIT license

## Authors & contributors

Check out all the [Authors and contributors](https://github.com/lumapps/dep-check/blob/master/doc/authors.md) of this project!

## Features

* [Auto-build your configuration file](https://github.com/lumapps/dep-check/blob/master/doc/usage.md#the-configuration-file)
* [Check your configuration](https://github.com/lumapps/dep-check/blob/master/doc/usage.md#checking-your-configuration)
* [Draw a dependency graph](https://github.com/lumapps/dep-check/blob/master/doc/usage.md#drawing-a-dependency-graph)

## Usage

Everything you need to know is in the [User Manual](https://github.com/lumapps/dep-check/blob/master/doc/usage.md)!

## Contributing

If you want to make a contribution, be sure to follow the [Contribution guide](https://github.com/lumapps/dep-check/blob/master/doc/contributing.md).

## History

Here is all the [histoy of this project](https://github.com/lumapps/dep-check/blob/master/doc/history.md).

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage) project template
